pub struct PartialSsaShare<S: PixSpec>(pub(crate) <PixScalar<S> as PrimeField>::Repr);Expand description
Share of a polynomial used to reconstruct a portion of the Session Stealth Address (SSA).
This corresponds to the P_ij(X) of the polynomial used to reconstruct the j-th portion of i-th SSA
at some value X.
The struct does not hold the X value, as it is usually computed from the
nonce.
See TaggedEncryptedPartialSsaShare and EncryptedPartialSsaShare for more details.
Tuple Fields
0: <PixScalar<S> as PrimeField>::ReprImplementations
Sourcepub fn encrypt(
self,
spi: &SsaPolynomialId<S::Pseudonym>,
ack_key: &HalfKey,
) -> Result<EncryptedPartialSsaShare<S>, S::Pseudonym>where
<<S as PixSpec>::Curve as Curve>::FieldBytesSize: Add<SsaPolyIndexPrefixSize>,
Sum<<<S as PixSpec>::Curve as Curve>::FieldBytesSize, SsaPolyIndexPrefixSize>: ArraySize,
pub fn encrypt(
self,
spi: &SsaPolynomialId<S::Pseudonym>,
ack_key: &HalfKey,
) -> Result<EncryptedPartialSsaShare<S>, S::Pseudonym>where
<<S as PixSpec>::Curve as Curve>::FieldBytesSize: Add<SsaPolyIndexPrefixSize>,
Sum<<<S as PixSpec>::Curve as Curve>::FieldBytesSize, SsaPolyIndexPrefixSize>: ArraySize,
Encrypts this partial SSA share using the given acknowledgement [HalfKey].